%global subagent_name mysql-snmp

Name:           librenms-snmp-subagent-mysql
Version:        1.2
Release:        1%{?dist}
Summary:        LibreNMS SNMP monitoring subagent for MySQL

Group:          Applications/Databases
License:        GPL
URL:            http://www.masterzen.fr/software-contributions/subagent-mysql-monitor-mysql-with-snmp
Source0:        %{subagent_name}-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  systemd

Requires:       librenms-snmp-agent
Requires:       perl(DBI)
Requires:       perl(DBD::mysql) >= 1.0
Requires:       perl(Math::BigInt::GMP)
Requires:       perl(Unix::Syslog)
Requires:       perl(SNMP)
Requires:       perl(NetSNMP::OID)
Requires:       perl(NetSNMP::ASN)
Requires:       perl(NetSNMP::agent)
Requires:       perl(NetSNMP::agent::default_store)
Requires:       perl(NetSNMP::default_store)

%description
LibreNMS mysql-snmp subagent is a small daemon that connects to a local
snmpd daemon to report statistics on a local or remote MySQL server.


%prep
%setup -q -n %{subagent_name}-%{version}

# fix issue
sed -i -e "s/Math::BigInt lib => 'GMP'/Math::BigInt::GMP/g" mysql-snmp
sed -i -e 's/mysql-snmp/subagent-mysql/g' mysql-snmp

# fix configuration
sed -i -e "s/\/etc\/snmp\/my.cnf/\%{_sysconfdir}\/snmp\/conf.d\/librenms-subagent-mysql.conf/g" redhat/mysql-snmp.sysconfig

# fix man page
sed -i -e 's/TH MYSQL-SNMP 1 "July 17, 2008"/TH MYSQL-SNMP 1.2 "November 25, 2023"/g' mysql-snmp.1
sed -i -e 's/mysql-snmp/subagent-mysql/g' mysql-snmp.1

cat >mysql-snmp.systemd <<EOF
[Unit]
Description=Enables monitoring of MySQL through SNMP
After=syslog.target network.target snmpd.service mysqld.service
Requires=snmpd.service mysqld.service

[Service]
Type=forking
Environment="OPTIONS=-d -p /run/subagent-mysql.pid"
EnvironmentFile=%{_sysconfdir}/sysconfig/subagent-mysql
ExecStart=%{_bindir}/subagent-mysql $OPTIONS
PIDFile=/run/subagent-mysql.pid

[Install]
WantedBy=default.target
EOF


%build


%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysconfdir}/{sysconfig,snmp/conf.d}
mkdir -p %{buildroot}%{_datadir}/snmp/subagent/mysql/mibs
mkdir -p %{buildroot}%{_mandir}/man1

install -Dpm 0755 mysql-snmp %{buildroot}%{_bindir}/subagent-mysql 
install -Dpm 0644 mysql-snmp.systemd %{buildroot}%{_unitdir}/librenms-subagent-mysql.service
install -Dpm 0644 redhat/mysql-snmp.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/subagent-mysql
install -Dpm 0600 my.cnf %{buildroot}%{_sysconfdir}/snmp/conf.d/librenms-subagent-mysql.conf
install -Dpm 0644 opennms/mysql.datacollection-config.xml %{buildroot}%{_datadir}/snmp/subagent/mysql/datacollection-config.xml
install -Dpm 0644 MYSQL-SERVER-MIB.txt %{buildroot}%{_datadir}/snmp/subagent/mysql/mibs
install -Dpm 0644 mysql-snmp.1 %{buildroot}%{_mandir}/man1/subagent-mysql.1
gzip %{buildroot}%{_mandir}/man1/subagent-mysql.1 


%post
%systemd_post librenms-subagent-mysql.service

%preun
%systemd_preun librenms-subagent-mysql.service


%files
%defattr(-,root,root,-)
%doc COPYING README
%dir %{_datadir}/snmp/subagent/mysql
%{_bindir}/subagent-mysql
%config(noreplace) %{_sysconfdir}/sysconfig/subagent-mysql
%config(noreplace) %{_sysconfdir}/snmp/conf.d/librenms-subagent-mysql.conf
%{_datadir}/snmp/subagent/mysql/datacollection-config.xml
%{_datadir}/snmp/subagent/mysql/mibs
%{_mandir}/man1/subagent-mysql.1*
%{_unitdir}/librenms-subagent-mysql.service


%changelog
* Sun Nov 26 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.2-1
- Rename to librenms-snmp-subagent-mysql
- Convert init.d to systemd script

* Mon Aug 15 2011 Brice Figureau <brice+debian@daysofwonder.com> - 1.2
- v1.2 release

* Wed Feb 17 2010 Robin Bowes <rpmbuild@yo61.net> - 1.0
- v1.0 release

* Mon Nov 16 2009 Robin Bowes <rpmbuild@yo61.net> - 1.0rc2-1
- Bump to rc2 version

* Sat Oct 31 2009 Brice Figureau <brice@daysofwonder.com> - 1.0rc1-1
- New version

* Sat Oct 24 2009 Brice Figureau <brice@daysofwonder.com> - 0.8-1
- New version
- Manpage compression in the spec

* Mon Sep 28 2009 Robin Bowes <rpmbuild@yo61.net> - 0.7-2
- Add opennms config files to package

* Mon Sep 28 2009 Robin Bowes <rpmbuild@yo61.net> - 0.7-1
- Initial RPM packaging
